/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.test.webid.testcases;

import java.math.BigInteger;

import org.bergnet.test.EarlTestCase;
import org.bergnet.test.webid.WebIDTestException;
import org.bergnet.webid.commons.FOAFBuilder;
import org.junit.Assert;
import org.junit.Test;

public class WrongModulus extends AbstractTestCase {
	public WrongModulus() throws Exception {
		init();

		id = "wrongmodulus.rdf";
		verificationQuery = "PREFIX earl: <http://www.w3.org/ns/earl#>\n" +
				"PREFIX wit: <http://www.w3.org/2005/Incubator/webid/earl/RelyingParty#>\n" +
				"ASK WHERE {\n" +
				"	?webidClaimAssertion\n" +
				"		earl:test wit:webidClaim;\n" +
				"		earl:result ?webidClaimResult;\n" +
				"		earl:subject ?webidClaimSubject.\n" +
				"	?webidClaimResult earl:outcome earl:failed.\n" +
				"	?webidClaimSubject wit:claimedIdentity ?webidString.\n" +
				"	?webidAuthenticationAssertion\n" +
				"		earl:test wit:webidAuthentication;\n" +
				"		earl:result ?webidAuthenticationResult.\n" +
				"	?webidAuthenticationResult earl:outcome earl:failed }";
	}

	public String buildFOAF() throws WebIDTestException {
		try {
			foaf = FOAFBuilder.build(webid.getUris(), webid.getModulus().add(new BigInteger("1")), webid.getPublicExponent(), FOAFBuilder.FORMAT_RDF_XML);

			dump("foaf.rdf", foaf);

			return foaf;
		} catch(Exception e) {
			throw new WebIDTestException("Can't build FOAF file", e);
		}
	}

	@EarlTestCase(
			url="http://www.w3.org/2005/Incubator/webid/earl/TestSuite#wrongModulus",
			title="Does the endpoint compare the modulus of the certificate and FOAF file?",
			description="Use a valid certificate and private key for authentication, but add 1 to the modulus in published FOAF file.")
	@Test
	public void test() throws Exception {
		generateWebID();
		buildFOAF();
		publishFOAF();
		login();
		verifyOutput();

		Assert.assertTrue(result);
	}
}
